========================
Team and repository tags
========================

.. image:: http://governance.openstack.org/badges/manila.svg
    :target: http://governance.openstack.org/reference/tags/index.html

.. Change things from this point on

======
MANILA
======

You have come across an OpenStack shared file system service.  It has
identified itself as "Manila."  It was abstracted from the Cinder
project.

* Wiki: https://wiki.openstack.org/Manila
* Developer docs: http://docs.openstack.org/developer/manila

Getting Started
---------------

If you'd like to run from the master branch, you can clone the git repo:

    git clone https://github.com/openstack/manila.git

For developer information please see
`HACKING.rst <https://github.com/openstack/manila/blob/master/HACKING.rst>`_

You can raise bugs here http://bugs.launchpad.net/manila

Python client
-------------

https://github.com/openstack/python-manilaclient.git
